@@ -17,12 +17,14 @@ def fetch_live_data(key,field):
             record = selection[0]
             return record[field]
         else:
+            print('Data format may have changed at '+URL)
             return None
     else:
+        print('Not getting a good response from ' + URL)
         return None
 
 def verrazano_speed():
     return fetch_live_data(key=VERRAZANO, field="speed")
 
 def bronx_speed():
-    return fetch_live_data(key=BRONX, field="speed")
\ No newline at end of file
+    return fetch_live_data(key=BRONX, field="speed")
