@@ -7,6 +7,15 @@ import threading
 import os
 
 
+def shorten_lists(v):
+    if isinstance(v, dict):
+        return dict([(k, shorten_lists(v1)) for k, v1 in v.items()])
+    elif isinstance(v, list) and len(v) > 50:
+        return v[:5] + v[-5:]
+    else:
+        return v
+
+
 class MicroPoll(MicroWriter):
 
     # --------------------------------------------
@@ -15,16 +24,19 @@ class MicroPoll(MicroWriter):
 
     def logger(self, data):
         """ Called after each attempt to poll data and send it """
+
         self.recent.append(data)
         if len(self.recent) > 100:
             self.recent = self.recent[-100:]
         if self.verbose:
-            pprint(data)
+            data_to_print = dict([(k,shorten_lists(v)) for k,v in data.items()])
+            pprint(data_to_print)
             print(' ', flush=True)
 
     def downtime(self):
         """ Also called after each attempt to send data """
-        # By default it does a little MUID mining, or a little more if the balance is sinking
+        # Here we do a little MUID mining, or a little more if the balance is sinking
+        # But note the default constructor arguments above, as mining=False by default
         self.maybe_bolster_balance_by_mining()
 
     def determine_next_value(self, source_value):
@@ -185,7 +197,7 @@ class MultiPoll(MicroPoll):
     def determine_next_values(self, source_values):
         """ Should receive raw source data and decides what to send, if anything
 
-            :param source_values   [ float ] or whatever type is returned by self.get_iex_realtime_price. Simplest would be [ float ]
+            :param source_values   [ float ] typically, though this method provides a way to relax that assumption
             :returns  [ float ]  or None
         """
 
@@ -206,7 +218,7 @@ class MultiPoll(MicroPoll):
                 interval:    int         minutes between polls
                 func_args    dict        optional dict of arguments to be passed to get_iex_realtime_price
 
-            """
+        """
         assert all([self.is_valid_name(name) for name in names]), 'name not valid'
         super().__init__(base_url=base_url or api_url(), write_key=write_key, verbose=verbose, func=func,
                          func_args=func_args, interval=interval, name='never_used.json')
@@ -236,7 +248,7 @@ class MultiPoll(MicroPoll):
                      'next_values': next_values,
                      'elapsed after polling': time.time() - start_time})
 
-        # Update the values with secondary get_iex_realtime_price
+        # Update the values with secondary
         if (self.secondary_func is not None) and (next_values is not None):
             send_values = self.apply_secondary_func(next_values)
         else:
@@ -257,7 +269,7 @@ class MultiPoll(MicroPoll):
 
 
 def default_change_criterion(old_values, new_values):
-    [abs(pp - pv) > 1e-6 for pp, pv in zip(old_values, new_values)]
+    return any([abs(pp - pv) > 1e-6 for pp, pv in zip(old_values, new_values)])
 
 
 class MultiChangePoll(MultiPoll):
@@ -265,16 +277,17 @@ class MultiChangePoll(MultiPoll):
     WARM = 1
 
     def __init__(self, names, func, interval, write_key="invalid_key", base_url=None, verbose=True, func_args=None,
-                 with_copulas=False, change_func=None, change_func_args=None, **kwargs):
+                 with_copulas=False, change_func=None, change_func_args=None, min_change_count=1, **kwargs):
         """  Create multiple streams by polling every 20 minutes, say
                 param:
-                names        [ str ]    stream name ending in .json
+                names        [ str ]    stream name ending in .json should include names of change streams as well, if change_func is not None
                 get_iex_realtime_price:        function    returns data from some live source, ideally [ float ] but you can override determine_next_values method
                 interval:    int         minutes between polls
                 func_args    dict        optional dict of arguments to be passed to get_iex_realtime_price
                 with_copulas bool        Whether to create derived copula streams, or just individual unrelated streams
                 change_func              Function acting directly on a list of value changes
                 change_func_args         Additional argument to change function
+                min_change_count         Minimum number of changes required to trigger an update
             """
         super().__init__(base_url=base_url or api_url(), write_key=write_key, verbose=verbose, func=func,
                          func_args=func_args, interval=interval, names=names, with_copulas=with_copulas, **kwargs)
@@ -283,6 +296,7 @@ class MultiChangePoll(MultiPoll):
         self.current_values = None
         self.change_func = change_func
         self.change_func_args = change_func_args
+        self.min_change_count=min_change_count
 
     def call_change_func(self, value_changes: [float]) -> [float]:
         if isinstance(self.change_func_args, list):
@@ -309,7 +323,7 @@ class MultiChangePoll(MultiPoll):
                 value_changes = [float(current_value) - float(prev_value) for current_value, prev_value in
                                  zip(self.current_values, self.prev_values)]
                 material_changes = [abs(vc) > 1e-6 for vc in value_changes]
-                if not any(material_changes):
+                if sum(material_changes)<=self.min_change_count:
                     self.feed_state = MultiChangePoll.COLD  # Feed is stale, don't judge
                     self.logger(
                         {'type': 'feed_status', 'message': "****  Feed unchanged at " + str(datetime.datetime.now())})
@@ -327,7 +341,7 @@ class MultiChangePoll(MultiPoll):
             self.prev_values = source_values
             if (self.prev_values is not None) and (self.prev_prev is not None):
                 material_changes = [abs(pp - pv) > 1e-6 for pp, pv in zip(self.prev_prev, self.prev_values)]
-                if any(material_changes):
+                if sum(material_changes)>=self.min_change_count:
                     self.feed_state = MultiChangePoll.WARM
                     self.logger(
                         {'type': 'feed_status', 'message': '**** Feed resumed at ' + str(datetime.datetime.now())})
