@@ -53,9 +53,13 @@ class MicroWriter(MicroReader):
         if res.status_code == 200:
             return res.json()
 
-    def set(self, name, value):
+    def set(self, name, value, with_percentiles=False):
         """ Create or update a stream """
-        res = requests.put(self.base_url + '/live/' + name, data={"write_key": self.write_key, "value": value})
+        if with_percentiles:
+            data = {"write_key": self.write_key, "value": value, "with_percentiles":"1"}
+        else:
+            data = {"write_key": self.write_key, "value": value}
+        res = requests.put(self.base_url + '/live/' + name, data)
         if res.status_code == 200:
             return res.json()
         elif res.status_code == 500:
@@ -66,22 +70,50 @@ class MicroWriter(MicroReader):
             print('', flush=True)
             raise Exception('Failed to update')
 
+    def cset_in_chunks(self, names, values):
+        """
+           Call cset on moderate sized chunks to avoid straining system
+        """
+        CHUNK_SIZE = 250
+        n = len(names)
+        assert len(names)==len(values)
+        chunks = [list(range(i, min(i + CHUNK_SIZE,n-1))) for i in range(0, n, CHUNK_SIZE)]
+        if len(chunks)>1:
+            chunks[-2] = chunks[-2]+chunks[-1] # Make sure there isn't a small chunk at the end
+            chunks = chunks[:-1]
+        last_res = None
+        for chunk in chunks:
+            try:
+                names_chunk = [ names[j] for j in chunk]
+                values_chunk = [ values[j] for j in chunk]
+            except IndexError:
+                print(chunk)
+                raise NotImplementedError("WTF")
+            last_res = self.cset(names=names_chunk, values=values_chunk)
+        return last_res
+
+
     def cset(self, names, values):
         """ Set multiple values linked by copula """
-        request_data = {"names": ",".join(names), "write_key": self.write_key}
-        request_data.update({"values": ",".join([str(v) for v in values])})
-        res = requests.put(self.base_url + '/copula/', data=request_data)
-        if self.verbose:
-            pprint.pprint(res.content)
-        if res.status_code == 200:
-            return res.json()
-        elif res.status_code == 500:
-            raise Exception("server error")
+        if len(names)>200:
+            return self.cset_in_chunks(names=names, values=values)
         else:
-            err = self.get_errors()
-            pprint.pprint(err)
-            print('', flush=True)
-            raise Exception('Failed to update')
+            request_data = {"names": ",".join(names), "write_key": self.write_key}
+            request_data.update({"values": ",".join([str(v) for v in values])})
+            res = requests.put(self.base_url + '/copula/', data=request_data)
+            print('Sent /copula/ request with '+str(len(names))+' names. ')
+            if res.status_code == 200:
+                res_json = res.json()
+                if isinstance(res_json,list) and len(res_json)>20:
+                    res_json = res_json[:5] + res_json[-5:]
+                return res_json
+            elif res.status_code == 500:
+                raise Exception("server error")
+            else:
+                err = self.get_errors()
+                pprint.pprint(err)
+                print('', flush=True)
+                raise Exception('Failed to update')
 
     def touch(self, name):
         """ Extend TTL of stream without updating """
